Crate cooklang_fs

source ·
cooklang-rs helper crate for the file system.

Utilities to deal with referencing recipe, images and data related to recipes that are in other files.

It implements an index into the file system to efficiently resolve recipes from a path. The index can be lazy or eager. Both created with new_index.

Structs

Enums

Constants

Functions