Crate cooklang_fs
source ·Expand description
cooklang-rs helper crate for the file system.
Utilities to deal with referencing recipe, images and data related to recipes that are in other files.
It implements an index into the file system to efficiently resolve recipes
from a path. The index can be lazy or eager. Both created with
new_index.
Structs
- Index of a directory for cooklang recipes
- Lazy index of a directory for cooklang recipes
Enums
Constants
- Valid image extensions
Functions
- Get all recipes from a path with a depth limit
- Check that all images for a recipe actually can reference it.
- Get a list of the images of the recipe
- Walks a single directory retrieving recipes and other directories